% zero_trend.m
% plots average distance of TIR zeros to the unit circle.
% the independent variable is the size of the TEQ.
%
% Written by Rick Martin, 09/18/2002
% Last updated 09/19/2002
% Cornell University Blind Equalization Research Group

% system parameters
Lws = [3:1:160]-1;       % equalizer length - 1
%Lws = [3:1:30]-1;        % (use this line for debugging)
nu = 32;                 % cyclic prefix length
Nlw = length(Lws);       % number of TEQ lengths to examine
Ncsa = 8;                % average over CSA loops 1 to Ncsa
ssx = 1;                 % signal power
SNR = 40;                % SNR in dB
ssn = ssx*10^(-SNR/10);  % noise power

% allocate memory
zb = zeros(nu,Nlw,Ncsa);

% loop through channel and TEQ length
hh = waitbar(0,'Computing many TEQs...');
for k=1:Ncsa
   k
   eval(['load csaloop',num2str(k),'.time;']);
   eval(['h = (csaloop',num2str(k),'(:,2));']);
   h = h/norm(h);       % unit norm channel
   Lh = length(h)-1;    % channel length - 1

   for i=1:Nlw
      Lw = Lws(i);      % equalizer length - 1
      Lc = Lw+Lh;       % length of combined channel - 1
      Rn = ssn*eye(Lw+1);
      % set delay (d)
      % use d = -1 to use the best d
      d = -1;
      if d == -1
         dmin = 1; dmax = Lc-nu-1;
      else
         dmin = d; dmax = d;
      end

      % MMSE solution (unit norm constraint)
      [b,w,dopt] = mmse_uec(h,dmin,dmax,nu,Lw,Rn);
      c1 = conv(h,w).';

      % compute zeros and sort them
      zb1 = roots(b);
      dz = (abs(zb1).^2-1).^2;  % squared distances to unit circle
      [dz,inds] = sort(dz);
      zb(:,i,k) = zb1(inds);    % sorted closest to furthest

      waitbar( ((k-1)*Nlw+i)/(Ncsa*Nlw), hh);
   end
end
close(hh);

rz = abs(zb);
arz = mean(abs(rz-1),3);

figure(1);  % linear scale
clf; set(0,'DefaultAxesFontSize',16);
plot(Lws+1,arz(1,:),'b-');
hold on
for j=2:nu
   plot(Lws+1,arz(j,:),'b-');
end
hold off
title('Distances of zeros of MMSE TIR to unit circle','FontSize',16);
xlabel('length of TEQ','FontSize',16);
ylabel('distance','FontSize',16);
v = axis;
axis([0 Lw(end)+1 v(3) v(4)]);
axis([1 160 0 2]);
grid on;

figure(2);  % log scale
clf; set(0,'DefaultAxesFontSize',16);
semilogy(Lws+1,arz(1,:),'b-');
hold on
for j=2:nu
   semilogy(Lws+1,arz(j,:),'b-');
end
hold off
title('Distances of zeros of MMSE TIR to unit circle','FontSize',16);
xlabel('length of TEQ','FontSize',16);
ylabel('distance','FontSize',16);
v = axis;
axis([0 Lw(end)+1 v(3) v(4)]);
grid on;
